<footer class="col-md-12">
  {%- block footer %}
  <nav class="container">
    <div class="row row-1">
      <div class="col-6">
	<a class="brand nav-link" href="http://developers.ringcentral.com/">Back to main site</a>
      </div>
      <div class="col-6">
	<ul class="nav flex-row ml-md-auto d-none d-md-flex pull-right">
	  <li class="nav-item"><a class="nav-link" href="http://www.ringcentral.com/legal.html" rel="nofollow">Legal</a></li>
	  <li class="nav-item"><a class="nav-link" href="https://www.ringcentral.com/legal/privacy-notice.html" rel="nofollow">Privacy Notice</a></li>
	  <li class="nav-item"><a class="nav-link" href="https://devcommunity.ringcentral.com/" rel="nofollow">Community</a></li>
	  <li class="nav-item"><a class="nav-link" href="https://medium.com/ringcentral-developers" rel="nofollow">Blog</a></li>
	</ul>
      </div>
    </div>
    <div class="row">
      <div class="col-6">
	{%- if config.copyright %}
	<p>&copy;{{ config.copyright }}</p>
	{%- endif %}
      </div>
      <div class="col-6">
	<ul class="nav flex-row ml-md-auto d-none d-md-flex pull-right">
	  <li><a class="nav-link footer-image-link footer-image-link-facebook" href="http://www.facebook.com/ringcentral">
	      <i class="fa fa-facebook"></i></a></li>
	  <li><a class="nav-link footer-image-link footer-image-link-twitter" href="http://twitter.com/ringcentraldevs">
	      <i class="fa fa-twitter"></i></a></li>
	  <li><a class="nav-link footer-image-link footer-image-link-linkedin" href="http://www.linkedin.com/company/ringcentral">
	      <i class="fa fa-linkedin"></i></a></li>
	  <li><a class="nav-link footer-image-link footer-image-link-youtube" href="http://www.youtube.com/ringcentral">
	      <i class="fa fa-youtube"></i></a></li>
	</ul>
      </div>
  </nav>
  {%- endblock %}
</footer>
<script type="text/javascript" src="{{ nav.homepage.url|url }}/js/menu.js"></script>