body {
  font-family: 'Lato',Helvetica,Arial,sans-serif !important;
}
.mega-dropdown {
  position: static !important;
  z-index: 10000;
}
.mega-dropdown-menu {
  padding: 0px 0px;
  width: 100%;
  box-shadow: none;
  border: 0;
  -webkit-box-shadow: none;
}
.mega-dropdown-menu > li > ul {
  padding: 0;
  margin: 0;
}
.mega-dropdown-menu > li > ul > li {
  list-style: none;
}
.mega-dropdown-menu > li > ul > li > a {
  display: block;
  color: #222;
  padding: 3px 5px;
}
.mega-dropdown-menu > li ul > li > a:hover,
.mega-dropdown-menu > li ul > li > a:focus {
  text-decoration: none;
}

.dropdown {
  z-index: 10000;
}
.horiz-nav-item.products {
  padding-left: 0;
}
.horiz-nav-item {
  padding: 20px 25px 20px 25px;
}
.navbar.primary {
  font-weight: 700;
  font-size: 13px;
  text-transform: uppercase;
  padding: 0;
}
.navbar.primary a {
  color: rgb(88, 88, 88);
}
.navbar.primary .active {
  background-color: rgb(240, 248, 251);
}
.navbar.primary .active a {
  color: rgb(6, 132, 189);
}
  .navbar.primary a.nav-link {
    padding: 14px;
  }

  .dropdown-menu {
      margin-top: 0;
  }
.dropdown-menu .nav-link {
  padding: 0;
}

.top-mininav {
  font-size: 13px;
  border-bottom: 1px solid rgb(228, 229, 235);
}
  .top-mininav li {
    margin-left: 20px;
  }
  .top-mininav a:visited,
  .top-mininav a {
    color: rgb(47, 47, 47);
  }

.engage #sidebar-nav {
    background-color: #616161;
}

.office #sidebar-nav {
    background-color: #616161;
}

.engage .navbar.secondary {
  background-color: #f80;
}
.office .navbar.secondary {
  background-color: #0684bd;
}
.navbar.secondary {
  font-weight: 300;
  height: 60px;
}
  .navbar.secondary ul.navbar-nav > li > a {
    color: white;
    font-size: 16px;
  }
  .navbar.secondary ul.navbar-nav > li {
    /*margin-right: 33px;*/
  }

.mega-dropdown-menu ul.row > li {
  list-style: none;
}
.mega-dropdown-menu > ul {
  padding: 0;
}

.office .secondary-nav-cta {
  background: url(../img/nav-secondary-office-arrow.svg) center right;
}
.office .secondary-nav-links a,
.office .secondary-nav-links .h4,
.office .secondary-nav-links h4,
.office .secondary-nav-cta .h3,
.office  .secondary-nav-cta h3 {
    color:rgb(6, 132, 189);
}
.office .secondary-nav-cta .btn {
    background-color:rgb(6, 132, 189);
    border-color:rgb(6, 132, 189);
}

.engage .secondary-nav-cta {
  background: url(../img/nav-secondary-engage-arrow.svg) center right;
}
.engage .secondary-nav-links a,
.engage .secondary-nav-links .h4,
.engage .secondary-nav-links h4,
.engage .secondary-nav-cta .h3,
.engage  .secondary-nav-cta h3 {
    color:#f80;
}
.engage .secondary-nav-cta .btn {
    background-color:#f80;
    border-color:#f80;
}

.secondary-nav-cta {
  color:rgb(103,103,103);
  font-size: 14px;
  background-size: cover;
  margin-right: 30px;
}
  .secondary-nav-cta .h3,
  .secondary-nav-cta h3 {
    font-weight: 600;
    font-size: 30px;
  }
  .secondary-nav-cta .btn {
    color: white;
  }

.secondary-nav-cta-content {
  width: 90%;
  padding: 30px 20px 40px 30px;
  font-weight: 400
}
@media only screen and (max-width: 992px) {
  .secondary-nav-cta-content {
    display:none;
  }
}

.secondary-nav-links {
  font-size: 14px;
  padding: 20px 0;
  font-weight: 500;  
}
  .secondary-nav-links ul {
    padding-inline-start: 0;
  }
  .secondary-nav-links li {
    list-style: none;
    margin-left: 10px;
    margin-top: 10px;
  }
  .secondary-nav-links a {
  }
  .secondary-nav-links .h4,
  .secondary-nav-links h4 {
    font-weight: 700;
    font-size: 18px;  
  }


.dpw-category-nav{
  display:flex;
  height:62px
}
.dpw-category-nav > ul {
  height:62px
}
.dpw-category{
  display:-webkit-box;
  display:-moz-box;
  display:-ms-flexbox;
  display:-webkit-flex;
  display:flex;
  position:relative
}
.dpw-category:after{
  content:"";
  display:none;
  position:absolute;
  left:50%;
  bottom:-1px;
  transform:translateX(-50%);
  border:10px solid transparent
}
.dpw-category.active:after{
  display:block
}
.dpw-category.active.office a{
  color:#0684bd;
  background-color:#f0f8fb
}
.dpw-category.active.office:after{
  border-bottom-color:#0684bd
}
.dpw-category.active.engage a{
  color:#f80;
  background-color:rgba(255,136,0,0.2)
}
.dpw-category.active.engage:after{
  border-bottom-color:#f80
}
.dpw-category a{
  display:-webkit-box;
  display:-moz-box;
  display:-ms-flexbox;
  display:-webkit-flex;
  display:flex;
  -webkit-align-items:center;
  align-items:center;
  padding:14px;
  font-size:13px;
  font-weight:bold;
  color:#585858;
  text-decoration:none
}
.dpw-category.office a:hover{
  color:#0684bd;background-color:#f0f8fb
}
.dpw-category.engage a:hover{
  color:#f80;background-color:rgba(255,136,0,0.2)
}
